interface ResultStat {
    rowsAffected: number;
    rowsRead: number | null;
    rowsWritten: number | null;
    queryDurationMs: number | null;
}
declare enum ColumnType {
    TEXT = 1,
    INTEGER = 2,
    REAL = 3,
    BLOB = 4
}
interface ColumnHeader {
    /**
     * The key of row data that this column represents.
     */
    name: string;
    /**
     * The display name of the column. This is the name that should be used when displaying the column to the user.
     */
    displayName: string;
    /**
     * The original type of the column returned from database driver.
     */
    originalType: string | null;
    /**
     * Provide hint to the client on how to render the column.
     * If not provided, the client should infer the type from the data.
     */
    type?: ColumnType;
}
interface ResultSet {
    rows: Record<string, unknown>[];
    headers: ColumnHeader[];
    stat: ResultStat;
    lastInsertRowid?: number;
}

interface ArrayBasedTransformProps<HeaderType> {
    rows: unknown[][];
    headers: HeaderType[];
    headersMapper: (header: HeaderType, headerIdx: number) => {
        name: string;
        type?: number;
        originalType: string | null;
    };
    transformValue?: (value: unknown, header: ColumnHeader) => unknown;
}
declare function transformArrayBasedResult<HeaderType>({ headers, headersMapper, rows, transformValue, }: ArrayBasedTransformProps<HeaderType>): {
    rows: Record<string, unknown>[];
    headers: ColumnHeader[];
};

declare function transformTursoResult(tursoResult: any): ResultSet;

declare function transformCloudflareD1(cloudflareResult: any): {
    stat: {
        rowsAffected: number;
        rowsRead: number;
        rowsWritten: number;
        queryDurationMs: number;
    };
    lastInsertRowid: number;
    rows: Record<string, unknown>[];
    headers: ColumnHeader[];
};

declare function transformMySQLResult(mysqlResult: any): {
    headers: any[];
    rows: any[];
    stat: {
        queryDurationMs: any;
        rowsAffected: number;
        rowsRead: any;
        rowsWritten: any;
    };
    lastInsertRowid: number;
} | {
    lastInsertRowid: any;
    stat: {
        queryDurationMs: any;
        rowsAffected: any;
        rowsRead: any;
        rowsWritten: any;
    };
    rows: Record<string, unknown>[];
    headers: ColumnHeader[];
};

declare function setPgParser(pgTypes: any): void;
declare function transformPgResult(pgResult: any): {
    stat: {
        queryDurationMs: number;
        rowsAffected: number;
        rowsRead: number;
        rowsWritten: number;
    };
    rows: Record<string, unknown>[];
    headers: ColumnHeader[];
};

export { type ColumnHeader, ColumnType, type ResultSet, type ResultStat, setPgParser, transformArrayBasedResult, transformCloudflareD1, transformMySQLResult, transformPgResult, transformTursoResult };
